Header

Struct Header 

#[repr(C, packed(1))]
pub struct Header { pub signature: [u8; 64], pub public_key: [u8; 32], pub blake3: [u8; 32], pub count: u32, pub flags: HeaderFlags, }

Fields

signature: [u8; 64]

NaCl signature of header data

public_key: [u8; 32]

NaCl public key used to generate signature

blake3: [u8; 32]

Blake3 sum of entry data

count: u32

Count of Entry structs, which starts immediately after header struct

flags: HeaderFlags

Generic flags contain data and entry struct properties

Implementations

Source

impl Header

pub fn new<'a>( data: &'a [u8], public_key: &PublicKey, ) -> Result<&'a Header, Error>

Parse header from raw header data and verify using public key

pub unsafe fn new_unchecked(data: &[u8]) -> Result<&Header, Error>

Parse header from raw header data without verification

pub fn count(&self) -> u32

pub fn entries_size(&self) -> Result<usize, Error>

Retrieve the size of the entries

pub fn total_size(&self) -> Result<usize, Error>

Retrieve the size of the Header and its entries

pub fn entries<'a>(&self, data: &'a [u8]) -> Result<&'a [Entry], Error>

Parse entries from raw entries data and verify using blake3

pub unsafe fn entries_unchecked(data: &[u8]) -> Result<&[Entry], Error>

Parse entries from raw entries data without verification